@@ -1,3 +1,3 @@
 from univariate.missing_value.missing_value_report import MissingValueReport
 from univariate.missing_value.missing_value_detector import MissingValueDetector
-from univariate.missing_value.missing_value_handler import MissingValueHandler
+from univariate.missing_value.handler.missing_value_handler import MissingValueHandler
